@@ -270,7 +270,8 @@ class DeploymentCache:
             'id': action.id,
             'name': action.name,
             'description': action.description,
-            'signature': []
+            'signature': [],
+            'deprecated': action.deprecated,
         }
 
         sig = action.signature
@@ -341,7 +342,8 @@ class DeploymentCache:
         type_repr = repr(type)
         style = qiime2.sdk.util.interrogate_collection_type(type)
 
-        if not qiime2.sdk.util.is_semantic_type(type):
+        if not qiime2.sdk.util.is_semantic_type(type) and \
+                not qiime2.sdk.util.is_union(type):
             if style.style is None:
                 if style.expr.predicate is not None:
                     type_repr = repr(style.expr.predicate)
@@ -380,6 +382,8 @@ class DeploymentCache:
             metavar = 'METADATA'
         elif style.style is not None and style.style != 'simple':
             metavar = 'VALUE'
+        elif qiime2.sdk.util.is_union(type):
+            metavar = 'VALUE'
         else:
             metavar = name_to_var[inner_type.name]
         if (metavar == 'NUMBER' and inner_type is not None
